package
module
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Dec 15, 2018
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
go-errctx
Golang library for structured error
Usage
See examples.
License
MIT
Documentation
¶
Package errctx is a library for structured error.
Error is a structured error.
Wrap returns an error added fields and msgs.
err should not be nil.
Cause returns a base error.
Error returns a message represents error.
Fields returns structured data of error.
type Fields map[string]interface{}
Fields is structured data of error.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.